@@ -231,7 +231,7 @@ class EPUBased(Coster):
 
     @property
     def euros(self):
-        P = 0.5
+        P = config("epu-price")
         return P * self.discounted_epus
 
     def as_dict(self):
@@ -668,6 +668,9 @@ class Costing:
 
         return rows
 
+    def html(self):
+        pass
+
     def csv(
         self,
         file=sys.stdout,
